NAME

papersway-ws-cmd - i3 workspace buttons protocol program for papersway

VERSION

version 3.000

SYNOPSIS

papersway-ws-cmd

DESCRIPTION

This is an i3 workspace buttons protocol program for use with papersway. It filters out papersway's hidden workspaces from the list of workspace buttons to display, and shows no buttons in the case that there is just one non-hidden workspace.

OPTIONS

None.

USAGE

When using papersway with i3, set the workspace_command configuration option for i3bar to this program. See papersway(1) for an example.

SEE ALSO

papersway(1)

AUTHOR

Sean Whitton <spwhitton@spwhitton.name>

COPYRIGHT AND LICENSE

This software is Copyright (c) 2019-2026 by Sean Whitton <spwhitton@spwhitton.name>.

This is free software, licensed under:

The GNU General Public License, Version 3, June 2007